import os
import sys


def setup_path():
    # Get pyton scripts directory
    python_base_path = os.path.dirname(sys.executable)

    # Check if base path is in the Scripts directory
    if os.path.basename(os.path.normpath(python_base_path)) != "Scripts":
        scripts_dir = os.path.join(python_base_path, "Scripts")
    else:
        scripts_dir = python_base_path

    # Add scripts directory to PATH if not already there
    if not os.path.exists(scripts_dir):
        raise SystemError(f"Scripts directory not found in {python_base_path}")

    # Add to path if not already there
    if scripts_dir not in os.environ["PATH"].split(os.pathsep):
        # Add the Scripts directory to the PATH
        os.environ["PATH"] += os.pathsep + scripts_dir
        print("Warn: Python/Scripts directory was not in PATH, added it.")



import os

import click
from .setup import setup_path
from .cmds import pyside_uic_run, pyside_designer_run
from typing import List


def pyside_uic(input, output):
    print(f"Converting {input} to {output}")
    pyside_uic_run(f"{input} -o {output}")


# icon filename to use
def convert_ui(ui_file: str, inplace: bool, target: str | None):
    if inplace:
        pyside_uic(ui_file, ui_file.replace(".ui", ".py"))
    else:
        assert target is not None, "Target directory must be specified when not converting in place"
        assert os.path.exists(target), f"Target directory {target} does not exist"
        pyside_uic(ui_file, os.path.join(target, os.path.basename(ui_file).replace(".ui", ".py")))


@click.group()
def cli():
    pass


@cli.command()
@click.argument("sources", type=click.Path(exists=True), required=True, nargs=-1)
@click.option("--inplace", "-i", is_flag=True, help="Convert the files in place")
@click.option("--target", "-t", help="Target directory for the converted files")
def convert(sources: List[str], inplace: bool, target: str | None):
    setup_path()

    for source in sources:
        convert_ui(source, inplace, target)


# edit command
@cli.command()
@click.argument("sources", type=click.Path(exists=True), required=True, nargs=-1)
def edit(sources: str):
    setup_path()
    pyside_designer_run(" ".join(sources))


if __name__ == "__main__":
    cli()



import distutils.spawn
import subprocess


def pyside_uic_run(command: str):
    EXECUTABLE = ["pyside6-uic", "pyside2-uic"]

    # Try to find the pyside-uic executable
    for executable_name in EXECUTABLE:
        executable = distutils.spawn.find_executable(executable_name)
        if executable:
            subprocess.run(f"{executable_name} {command}", shell=True)
            return

    raise SystemError("pyside-uic executable not found")


def pyside_designer_run(command: str):
    EXECUTABLE = ["pyside6-designer", "pyside2-designer"]

    # Try to find the pyside-uic executable
    for executable_name in EXECUTABLE:
        executable = distutils.spawn.find_executable(executable_name)
        if executable:
            subprocess.run(f"{executable_name} {command}", shell=True)
            return

    raise SystemError("pyside-designer executable not found")
